Re: [PHP-CVS] cvs: php4 /ext/standard basic_functions.c basic_functions.huser_filters.c

2003-01-05 Thread Wez Furlong
Because there is no structure to return :)
This function returns an array of the names of the filters available for
use via stream_filter_(prepend|append).

--Wez.

On Sat, 4 Jan 2003, Sterling Hughes wrote:

  pollita Sat Jan  4 22:24:38 2003 EDT
 
Modified files:
  /php4/ext/standard  basic_functions.c basic_functions.h
  user_filters.c
Log:
Added stream_get_filters(); to list registered filters
 

 How about returning the entire stream structure?

 -Sterling

 --
 PHP CVS Mailing List (http://www.php.net/)
 To unsubscribe, visit: http://www.php.net/unsub.php





-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4(PHP_4_3) /ext/standard php_incomplete_class.h

2003-01-05 Thread Edin Kadribasic
edink   Sun Jan  5 08:02:03 2003 EDT

  Modified files:  (Branch: PHP_4_3)
/php4/ext/standard  php_incomplete_class.h 
  Log:
  Fixed ZTS build.
  
  
Index: php4/ext/standard/php_incomplete_class.h
diff -u php4/ext/standard/php_incomplete_class.h:1.9.4.2 
php4/ext/standard/php_incomplete_class.h:1.9.4.3
--- php4/ext/standard/php_incomplete_class.h:1.9.4.2Sat Jan  4 14:42:37 2003
+++ php4/ext/standard/php_incomplete_class.hSun Jan  5 08:02:02 2003
@@ -16,7 +16,7 @@
+--+
 */
 
-/* $Id: php_incomplete_class.h,v 1.9.4.2 2003/01/04 19:42:37 helly Exp $ */
+/* $Id: php_incomplete_class.h,v 1.9.4.3 2003/01/05 13:02:02 edink Exp $ */
 
 #ifndef PHP_INCOMPLETE_CLASS_H
 #define PHP_INCOMPLETE_CLASS_H
@@ -29,7 +29,7 @@
 #define PHP_SET_CLASS_ATTRIBUTES(struc)   
 \
/* OBJECTS_FIXME: Fix for new object model */  
 \
if (Z_OBJCE_P(struc) == BG(incomplete_class)) {
 \
-   class_name = php_lookup_class_name(struc, name_len, 1);   
 \
+   class_name = php_lookup_class_name(struc, name_len, 1 TSRMLS_CC); 
+ \
free_class_name = 1;   
 \
} else {   
 \
class_name = Z_OBJCE_P(struc)-name;   
 \



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /sapi/apache php4apache.dsp

2003-01-05 Thread Zeev Suraski
zeevSun Jan  5 10:09:11 2003 EDT

  Modified files:  
/php4/sapi/apache   php4apache.dsp 
  Log:
  Make the .dsp use the php4build build directories
  
  
Index: php4/sapi/apache/php4apache.dsp
diff -u php4/sapi/apache/php4apache.dsp:1.14 php4/sapi/apache/php4apache.dsp:1.15
--- php4/sapi/apache/php4apache.dsp:1.14Thu Jan  2 09:19:29 2003
+++ php4/sapi/apache/php4apache.dsp Sun Jan  5 10:09:11 2003
@@ -44,7 +44,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
 # ADD BASE CPP /nologo /MT /W3 /GX /O2 /D WIN32 /D NDEBUG /D _WINDOWS /D 
_MBCS /D _USRDLL /D APACHEPHP4_EXPORTS /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I ...\..\include /I ..\..\win32 /I 
..\..\Zend /I ..\.. /I ..\..\..\bindlib_w32 /I 
..\..\..\php_build\apache\src\include /I ..\..\main /I ..\..\TSRM /I 
..\..\regex /D ZEND_DEBUG=0 /D NDEBUG /D ZTS /D ZEND_WIN32 /D PHP_WIN32 /D 
_WINDOWS /D _USRDLL /D APACHEPHP4_EXPORTS /D WIN32 /D _MBCS /D 
APACHE_READDIR_H /YX /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I ...\..\include /I ..\..\win32 /I 
+..\..\Zend /I ..\.. /I ..\..\..\bindlib_w32 /I ..\..\..\php_build\includes /I 
+..\..\main /I ..\..\TSRM /I ..\..\regex /D ZEND_DEBUG=0 /D NDEBUG /D ZTS /D 
+ZEND_WIN32 /D PHP_WIN32 /D _WINDOWS /D _USRDLL /D APACHEPHP4_EXPORTS /D 
+WIN32 /D _MBCS /D APACHE_READDIR_H /YX /FD /c
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD BASE RSC /l 0x409 /d NDEBUG
@@ -54,7 +54,7 @@
 # ADD BSC32 /nologo
 LINK32=link.exe
 # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib 
advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib 
/nologo /dll /machine:I386
-# ADD LINK32 php4ts.lib ApacheCore.lib kernel32.lib user32.lib gdi32.lib winspool.lib 
comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib 
odbccp32.lib /nologo /base:0x6000 /version:4.0 /dll /machine:I386 
/libpath:..\..\..\php_build\apache\src\corer /libpath:..\..\Release_TS 
/libpath:..\..\TSRM\Release_TS /libpath:..\..\Zend\Release_TS
+# ADD LINK32 php4ts.lib ApacheCore.lib kernel32.lib user32.lib gdi32.lib winspool.lib 
+comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib 
+odbccp32.lib /nologo /base:0x6000 /version:4.0 /dll /machine:I386 
+/libpath:..\..\..\php_build\release /libpath:..\..\Release_TS 
+/libpath:..\..\TSRM\Release_TS /libpath:..\..\Zend\Release_TS
 
 !ELSEIF  $(CFG) == php4apache - Win32 Debug_TS
 
@@ -70,7 +70,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
 # ADD BASE CPP /nologo /MT /W3 /GX /O2 /D WIN32 /D NDEBUG /D _WINDOWS /D 
_MBCS /D _USRDLL /D APACHEPHP4_EXPORTS /YX /FD /c
-# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I ...\..\include /I ..\..\win32 /I 
..\..\Zend /I ..\.. /I ..\..\..\bindlib_w32 /I 
..\..\..\php_build\apache\src\include /I ..\..\main /I ..\..\TSRM /I 
..\..\regex /D _DEBUG /D ZEND_DEBUG=1 /D ZTS /D ZEND_WIN32 /D PHP_WIN32 /D 
_WINDOWS /D _USRDLL /D APACHEPHP4_EXPORTS /D WIN32 /D _MBCS /D 
APACHE_READDIR_H /FR /YX /FD /c
+# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I ...\..\include /I ..\..\win32 /I 
+..\..\Zend /I ..\.. /I ..\..\..\bindlib_w32 /I ..\..\..\php_build\includes /I 
+..\..\main /I ..\..\TSRM /I ..\..\regex /D _DEBUG /D ZEND_DEBUG=1 /D ZTS /D 
+ZEND_WIN32 /D PHP_WIN32 /D _WINDOWS /D _USRDLL /D APACHEPHP4_EXPORTS /D 
+WIN32 /D _MBCS /D APACHE_READDIR_H /FR /YX /FD /c
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD BASE RSC /l 0x409 /d NDEBUG
@@ -80,7 +80,7 @@
 # ADD BSC32 /nologo
 LINK32=link.exe
 # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib 
advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib 
/nologo /dll /machine:I386
-# ADD LINK32 php4ts_debug.lib ApacheCore.lib kernel32.lib user32.lib gdi32.lib 
winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib 
odbc32.lib odbccp32.lib /nologo /base:0x6000 /version:4.0 /dll /incremental:yes 
/debug /machine:I386 /pdbtype:sept /libpath:..\..\..\php_build\apache\src\cored 
/libpath:..\..\Debug_TS /libpath:..\..\TSRM\Debug_TS /libpath:..\..\Zend\Debug_TS
+# ADD LINK32 php4ts_debug.lib ApacheCore.lib kernel32.lib user32.lib gdi32.lib 
+winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib 
+odbc32.lib odbccp32.lib /nologo /base:0x6000 /version:4.0 /dll /incremental:yes 
+/debug /machine:I386 /pdbtype:sept /libpath:..\..\..\php_build\release 
+/libpath:..\..\Debug_TS /libpath:..\..\TSRM\Debug_TS 
+/libpath:..\..\Zend\Debug_TS
 
 !ELSEIF  $(CFG) == php4apache - Win32 Release_TS_inline
 
@@ -96,7 +96,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
 # ADD BASE CPP /nologo /MT /W3 /GX /O2 /D WIN32 /D NDEBUG /D _WINDOWS /D 
_MBCS /D _USRDLL /D APACHEPHP4_EXPORTS /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I ...\..\include /I ..\..\win32 /I 
..\..\Zend /I ..\.. 

[PHP-CVS] cvs: php4 /ext/gd gd_bundled.dsp

2003-01-05 Thread Sebastian Bergmann
sebastian   Sun Jan  5 11:32:02 2003 EDT

  Modified files:  
/php4/ext/gdgd_bundled.dsp 
  Log:
  Define HAVE_GD_GIF_READ.
  
Index: php4/ext/gd/gd_bundled.dsp
diff -u php4/ext/gd/gd_bundled.dsp:1.7 php4/ext/gd/gd_bundled.dsp:1.8
--- php4/ext/gd/gd_bundled.dsp:1.7  Thu Oct 31 20:20:05 2002
+++ php4/ext/gd/gd_bundled.dsp  Sun Jan  5 11:32:01 2003
@@ -43,8 +43,8 @@
 # PROP Intermediate_Dir Release_TS
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
-# ADD BASE CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=0 /D WIN32 /D NDEBUG /D 
_WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D 
HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 /FR /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=0 /D HAVE_LIBGD15=1 /D 
HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D 
ZEND_WIN32 /D PHP_WIN32 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D 
HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D HAVE_LIBGD20=1 /D 
USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D HAVE_GD_STRINGTTF=1 /D 
HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D HAVE_LIBJPEG /D HAVE_GD_GD2 /FR 
/FD /c
+# ADD BASE CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
+..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=0 /D WIN32 /D NDEBUG /D 
+_WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
+HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D 
+HAVE_GD_WBMP /D HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 
+/FR /YX /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
+..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=0 /D HAVE_LIBGD15=1 
+/D HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 
+/D ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
+HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
+HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
+HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
+HAVE_LIBJPEG /D HAVE_GD_GD2 /FR /FD /c
 # SUBTRACT CPP /YX
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32
@@ -73,8 +73,8 @@
 # PROP Intermediate_Dir Debug_TS
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
-# ADD BASE CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I 
..\..\Zend /I ..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=1 /D WIN32 /D 
NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D 
HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 /FR /YX /FD /c
-# ADD CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=1 /D HAVE_LIBGD15 /D 
HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D 
ZEND_WIN32 /D PHP_WIN32 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D 
HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D HAVE_LIBGD20=1 /D 
USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D HAVE_GD_STRINGTTF=1 /D 
HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D HAVE_LIBJPEG /D HAVE_GD_GD2 /FR 
/FD /c
+# ADD BASE CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I 
+..\..\Zend /I ..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=1 /D WIN32 /D 
+NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
+HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D 
+HAVE_GD_WBMP /D HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 
+/FR /YX /FD /c
+# ADD CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I ..\..\Zend /I 
+..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=1 /D HAVE_LIBGD15 
+/D HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 
+/D ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
+HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
+HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
+HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
+HAVE_LIBJPEG /D HAVE_GD_GD2 /FR /FD /c
 # SUBTRACT CPP /YX
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/mysql php_mysql.c

2003-01-05 Thread Georg Richter
georg   Sun Jan  5 15:53:06 2003 EDT

  Modified files:  
/php4/ext/mysql php_mysql.c 
  Log:
  fixed bug #21435
  
  
Index: php4/ext/mysql/php_mysql.c
diff -u php4/ext/mysql/php_mysql.c:1.179 php4/ext/mysql/php_mysql.c:1.180
--- php4/ext/mysql/php_mysql.c:1.179Tue Dec 31 11:07:03 2002
+++ php4/ext/mysql/php_mysql.c  Sun Jan  5 15:53:06 2003
@@ -18,7 +18,7 @@
+--+
 */
  
-/* $Id: php_mysql.c,v 1.179 2002/12/31 16:07:03 sebastian Exp $ */
+/* $Id: php_mysql.c,v 1.180 2003/01/05 20:53:06 georg Exp $ */
 
 /* TODO:
  *
@@ -987,7 +987,7 @@
Returns a string containing information about the most recent query */
 PHP_FUNCTION(mysql_info)
 {
-   zval **mysql_link;
+   zval *mysql_link;
int id = -1;
char *str;
php_mysql_conn *mysql;



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




Re: [PHP-CVS] cvs: php4 /ext/mysql php_mysql.c

2003-01-05 Thread Derick Rethans
On Sun, 5 Jan 2003, Georg Richter wrote:

 georg Sun Jan  5 15:53:06 2003 EDT
 
   Modified files:  
 /php4/ext/mysql   php_mysql.c 
   Log:
   fixed bug #21435

Can you MFH this too?

Derick

-- 

-
 Derick Rethans http://derickrethans.nl/ 
 PHP Magazine - PHP Magazine for Professionals   http://php-mag.net/
-


-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/mcrypt mcrypt.c

2003-01-05 Thread Edin Kadribasic
edink   Sun Jan  5 20:26:14 2003 EDT

  Modified files:  
/php4/ext/mcryptmcrypt.c 
  Log:
  Comment out non ANSI C standard comliant code. Fixes win32 build.
  
  
Index: php4/ext/mcrypt/mcrypt.c
diff -u php4/ext/mcrypt/mcrypt.c:1.79 php4/ext/mcrypt/mcrypt.c:1.80
--- php4/ext/mcrypt/mcrypt.c:1.79   Fri Jan  3 14:49:44 2003
+++ php4/ext/mcrypt/mcrypt.cSun Jan  5 20:26:14 2003
@@ -16,7 +16,7 @@
|  Derick Rethans [EMAIL PROTECTED]  |
+--+
  */
-/* $Id: mcrypt.c,v 1.79 2003/01/03 19:49:44 derick Exp $ */
+/* $Id: mcrypt.c,v 1.80 2003/01/06 01:26:14 edink Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include config.h
@@ -168,8 +168,11 @@
if (argc  (a) || argc  (b)) {
 \
WRONG_PARAM_COUNT; 
 \
}
-#warning Invalidate resource if the param count is wrong, or other problems
-#warning occurred during functions.
+/*
+ * #warning is not ANSI C
+ * #warning Invalidate resource if the param count is wrong, or other problems
+ * #warning occurred during functions.
+ */
 
 #define MCRYPT_GET_CRYPT_ARGS 
 \
switch (argc) {
 \



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/gd gd_bundled.dsp

2003-01-05 Thread Edin Kadribasic
edink   Sun Jan  5 20:39:08 2003 EDT

  Modified files:  
/php4/ext/gdgd_bundled.dsp 
  Log:
  Complete gif readonly support addition by adding missing gd_gif_in.c
  file to the project.
  
  
Index: php4/ext/gd/gd_bundled.dsp
diff -u php4/ext/gd/gd_bundled.dsp:1.8 php4/ext/gd/gd_bundled.dsp:1.9
--- php4/ext/gd/gd_bundled.dsp:1.8  Sun Jan  5 11:32:01 2003
+++ php4/ext/gd/gd_bundled.dsp  Sun Jan  5 20:39:08 2003
@@ -210,6 +210,10 @@
 # End Source File
 # Begin Source File
 
+SOURCE=.\libgd\gd_gif_in.c
+# End Source File
+# Begin Source File
+
 SOURCE=.\libgd\gd_io.c
 
 !IF  $(CFG) == gd_bundled - Win32 Release_TS GD2



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/standard user_filters.c /main php_streams.h streams.c

2003-01-05 Thread Sara Golemon
pollita Sun Jan  5 23:06:40 2003 EDT

  Modified files:  
/php4/main  streams.c php_streams.h 
/php4/ext/standard  user_filters.c 
  Log:
  Expose stream_filters_hash so that it can be searched by stream_get_filters()
  
  
Index: php4/main/streams.c
diff -u php4/main/streams.c:1.140 php4/main/streams.c:1.141
--- php4/main/streams.c:1.140   Wed Jan  1 04:58:17 2003
+++ php4/main/streams.c Sun Jan  5 23:06:40 2003
@@ -20,7 +20,7 @@
+--+
  */
 
-/* $Id: streams.c,v 1.140 2003/01/01 09:58:17 wez Exp $ */
+/* $Id: streams.c,v 1.141 2003/01/06 04:06:40 pollita Exp $ */
 
 #define _GNU_SOURCE
 #include php.h
@@ -386,6 +386,11 @@
 
 /* {{{ filter API */
 static HashTable stream_filters_hash;
+
+PHPAPI HashTable *php_get_stream_filters_hash()
+{
+   return stream_filters_hash;
+}
 
 PHPAPI int php_stream_filter_register_factory(const char *filterpattern, 
php_stream_filter_factory *factory TSRMLS_DC)
 {
Index: php4/ext/standard/user_filters.c
diff -u php4/ext/standard/user_filters.c:1.5 php4/ext/standard/user_filters.c:1.6
--- php4/ext/standard/user_filters.c:1.5Sun Jan  5 17:24:49 2003
+++ php4/ext/standard/user_filters.cSun Jan  5 23:06:40 2003
@@ -17,7 +17,7 @@
+--+
 */
 
-/* $Id: user_filters.c,v 1.5 2003/01/05 22:24:49 pollita Exp $ */
+/* $Id: user_filters.c,v 1.6 2003/01/06 04:06:40 pollita Exp $ */
 
 #include php.h
 #include php_globals.h
@@ -417,6 +417,7 @@
 {
char *filter_name;
int key_flags, filter_name_len = 0;
+   HashTable *filters_hash;
 
if (ZEND_NUM_ARGS() != 0) {
WRONG_PARAM_COUNT;
@@ -424,10 +425,12 @@
 
array_init(return_value);
 
-   if (BG(user_filter_map)) {
-   for(zend_hash_internal_pointer_reset(BG(user_filter_map));
-   (key_flags = zend_hash_get_current_key_ex(BG(user_filter_map), 
filter_name, filter_name_len, NULL, 0, NULL)) != HASH_KEY_NON_EXISTANT;
-   zend_hash_move_forward(BG(user_filter_map)))
+   filters_hash = php_get_stream_filters_hash();
+
+   if (filters_hash) {
+   for(zend_hash_internal_pointer_reset(filters_hash);
+   (key_flags = zend_hash_get_current_key_ex(filters_hash, 
+filter_name, filter_name_len, NULL, 0, NULL)) != HASH_KEY_NON_EXISTANT;
+   zend_hash_move_forward(filters_hash))
if (key_flags == HASH_KEY_IS_STRING)
add_next_index_stringl(return_value, 
filter_name, filter_name_len, 1);
}



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/gd gd_bundled.dsp

2003-01-05 Thread Frank M. Kromann
fmk Sun Jan  5 23:28:49 2003 EDT

  Modified files:  
/php4/ext/gdgd_bundled.dsp 
  Log:
  enable imageftbbox() and imagefttext() on WIn32
  
Index: php4/ext/gd/gd_bundled.dsp
diff -u php4/ext/gd/gd_bundled.dsp:1.9 php4/ext/gd/gd_bundled.dsp:1.10
--- php4/ext/gd/gd_bundled.dsp:1.9  Sun Jan  5 20:39:08 2003
+++ php4/ext/gd/gd_bundled.dsp  Sun Jan  5 23:28:49 2003
@@ -44,7 +44,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
 # ADD BASE CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=0 /D WIN32 /D NDEBUG /D 
_WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D 
HAVE_GD_WBMP /D HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 
/FR /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=0 /D HAVE_LIBGD15=1 /D 
HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D 
ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
HAVE_LIBJPEG /D HAVE_GD_GD2 /FR /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I ..\.. /I ..\..\main /I ..\..\Zend /I 
+..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=0 /D HAVE_LIBGD15=1 
+/D HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 
+/D ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
+HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
+HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
+HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
+HAVE_LIBJPEG /D HAVE_GD_GD2 /D HAVE_GD_STRINGFTEX /FR /FD /c
 # SUBTRACT CPP /YX
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32
@@ -74,7 +74,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir 
 # ADD BASE CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I 
..\..\Zend /I ..\..\..\bindlib_w32 /I ..\..\TSRM /D ZEND_DEBUG=1 /D WIN32 /D 
NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D ZEND_WIN32 /D PHP_WIN32 /D 
HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D HAVE_GD_PNG /D HAVE_GD_JPG /D 
HAVE_GD_WBMP /D HAVE_LIBGD13=1 /D HAVE_LIBGD=1 /D HAVE_LIBGD15=1 /D HAVE_LIBGD204=1 
/FR /YX /FD /c
-# ADD CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I ..\..\Zend /I 
..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=1 /D HAVE_LIBGD15 /D 
HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 /D 
ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
HAVE_LIBJPEG /D HAVE_GD_GD2 /FR /FD /c
+# ADD CPP /nologo /MDd /W3 /GX /ZI /Od /I ..\.. /I ..\..\main /I ..\..\Zend /I 
+..\..\..\bindlib_w32 /I ..\..\TSRM /I libgd /D ZEND_DEBUG=1 /D HAVE_LIBGD15 
+/D HAVE_LIBGD204=1 /D WIN32 /D NDEBUG /D _WINDOWS /D COMPILE_DL_GD /D ZTS=1 
+/D ZEND_WIN32 /D PHP_WIN32 /D HAVE_GD_GIF_READ=1 /D HAVE_GDIMAGECOLORRESOLVE=1 /D 
+HAVE_GD_PNG /D HAVE_GD_JPG /D HAVE_GD_WBMP /D HAVE_LIBGD=1 /D HAVE_LIBGD13=1 /D 
+HAVE_LIBGD20=1 /D USE_GD_IOCTX /D HAVE_LIBFREETYPE=1 /D USE_GD_IMGSTRTTF /D 
+HAVE_GD_STRINGTTF=1 /D HAVE_GD_BUNDLED=1 /D MSWIN32 /D HAVE_LIBPNG /D 
+HAVE_LIBJPEG /D HAVE_GD_GD2 /D HAVE_GD_STRINGFTEX /FR /FD /c
 # SUBTRACT CPP /YX
 # ADD BASE MTL /nologo /D NDEBUG /mktyplib203 /win32
 # ADD MTL /nologo /D NDEBUG /mktyplib203 /win32



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php




[PHP-CVS] cvs: php4 /ext/standard filters.c

2003-01-05 Thread Sara Golemon
pollita Mon Jan  6 00:22:06 2003 EDT

  Modified files:  
/php4/ext/standard  filters.c 
  Log:
  Added string.toupper and string.tolower filters and generalized non-op filter methods
  
  
Index: php4/ext/standard/filters.c
diff -u php4/ext/standard/filters.c:1.3 php4/ext/standard/filters.c:1.4
--- php4/ext/standard/filters.c:1.3 Wed Jan  1 07:36:06 2003
+++ php4/ext/standard/filters.c Mon Jan  6 00:22:06 2003
@@ -17,7 +17,7 @@
+--+
 */
 
-/* $Id: filters.c,v 1.3 2003/01/01 12:36:06 sebastian Exp $ */
+/* $Id: filters.c,v 1.4 2003/01/06 05:22:06 pollita Exp $ */
 
 #include php.h
 #include php_globals.h
@@ -25,6 +25,18 @@
 #include ext/standard/file.h
 #include ext/standard/php_string.h
 
+/* {{{ common no-opperation methods */
+static int commonfilter_nop_flush(php_stream *stream, php_stream_filter *thisfilter, 
+int closing TSRMLS_DC)
+{
+   return php_stream_filter_flush_next(stream, thisfilter, closing);
+}
+
+static int commonfilter_nop_eof(php_stream *stream, php_stream_filter *thisfilter 
+TSRMLS_DC)
+{
+   return php_stream_filter_eof_next(stream, thisfilter);
+}
+/* }}} */
+
 /* {{{ rot13 stream filter implementation */
 static char rot13_from[] = abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ;
 static char rot13_to[] = nopqrstuvwxyzabcdefghijklmNOPQRSTUVWXYZABCDEFGHIJKLM;
@@ -63,21 +75,11 @@
return read;
 }
 
-static int strfilter_rot13_flush(php_stream *stream, php_stream_filter *thisfilter, 
int closing TSRMLS_DC)
-{
-   return php_stream_filter_flush_next(stream, thisfilter, closing);
-}
-
-static int strfilter_rot13_eof(php_stream *stream, php_stream_filter *thisfilter 
TSRMLS_DC)
-{
-   return php_stream_filter_eof_next(stream, thisfilter);
-}
-
 static php_stream_filter_ops strfilter_rot13_ops = {
strfilter_rot13_write,
strfilter_rot13_read,
-   strfilter_rot13_flush,
-   strfilter_rot13_eof,
+   commonfilter_nop_flush,
+   commonfilter_nop_eof,
NULL,
string.rot13
 };
@@ -93,11 +95,124 @@
 };
 /* }}} */
 
+/* {{{ string.toupper / string.tolower stream filter implementation */
+static char lowercase[] = abcdefghijklmnopqrstuvwxyz;
+static char uppercase[] = ABCDEFGHIJKLMNOPQRSTUVWXYZ;
+
+static size_t strfilter_toupper_write(php_stream *stream, php_stream_filter 
+*thisfilter,
+   const char *buf, size_t count TSRMLS_DC)
+{
+   char tmpbuf[1024];
+   size_t chunk;
+   size_t wrote = 0;
+
+   while (count  0) {
+   chunk = count;
+   if (chunk  sizeof(tmpbuf))
+   chunk = sizeof(tmpbuf);
+
+   PHP_STRLCPY(tmpbuf, buf, sizeof(tmpbuf), chunk);
+   buf += chunk;
+   count -= chunk;
+
+   php_strtr(tmpbuf, chunk, lowercase, uppercase, 26);
+   wrote += php_stream_filter_write_next(stream, thisfilter, tmpbuf, 
+chunk);
+   }
+
+   return wrote;
+}
+
+static size_t strfilter_tolower_write(php_stream *stream, php_stream_filter 
+*thisfilter,
+   const char *buf, size_t count TSRMLS_DC)
+{
+   char tmpbuf[1024];
+   size_t chunk;
+   size_t wrote = 0;
+
+   while (count  0) {
+   chunk = count;
+   if (chunk  sizeof(tmpbuf))
+   chunk = sizeof(tmpbuf);
+
+   PHP_STRLCPY(tmpbuf, buf, sizeof(tmpbuf), chunk);
+   buf += chunk;
+   count -= chunk;
+
+   php_strtr(tmpbuf, chunk, uppercase, lowercase, 26);
+   wrote += php_stream_filter_write_next(stream, thisfilter, tmpbuf, 
+chunk);
+   }
+
+   return wrote;
+}
+
+static size_t strfilter_toupper_read(php_stream *stream, php_stream_filter 
+*thisfilter,
+   char *buf, size_t count TSRMLS_DC)
+{
+   size_t read;
+
+   read = php_stream_filter_read_next(stream, thisfilter, buf, count);
+   php_strtr(buf, read, lowercase, uppercase, 26);
+
+   return read;
+}
+
+static size_t strfilter_tolower_read(php_stream *stream, php_stream_filter 
+*thisfilter,
+   char *buf, size_t count TSRMLS_DC)
+{
+   size_t read;
+
+   read = php_stream_filter_read_next(stream, thisfilter, buf, count);
+   php_strtr(buf, read, uppercase, lowercase, 26);
+
+   return read;
+}
+
+static php_stream_filter_ops strfilter_toupper_ops = {
+   strfilter_toupper_write,
+   strfilter_toupper_read,
+   commonfilter_nop_flush,
+   commonfilter_nop_eof,
+   NULL,
+   string.toupper
+};
+
+static php_stream_filter_ops strfilter_tolower_ops = {
+   strfilter_tolower_write,
+   strfilter_tolower_read,
+   commonfilter_nop_flush,
+   commonfilter_nop_eof,
+   NULL,
+   string.tolower
+};
+
+static php_stream_filter *strfilter_toupper_create(const char *filtername, const char 
+*filterparams,
+   int 

[PHP-CVS] cvs: php4 /ext/standard basic_functions.c

2003-01-05 Thread Anantha Kesari H Y
hyanantha   Mon Jan  6 00:59:18 2003 EDT

  Modified files:  
/php4/ext/standard  basic_functions.c 
  Log:
  Added #ifdef HAVE_SYSLOG_H around syslog function in the whole file to avoid link 
failure.
  
  
Index: php4/ext/standard/basic_functions.c
diff -u php4/ext/standard/basic_functions.c:1.554 
php4/ext/standard/basic_functions.c:1.555
--- php4/ext/standard/basic_functions.c:1.554   Sat Jan  4 22:24:38 2003
+++ php4/ext/standard/basic_functions.c Mon Jan  6 00:59:17 2003
@@ -17,7 +17,7 @@
+--+
  */
 
-/* $Id: basic_functions.c,v 1.554 2003/01/05 03:24:38 pollita Exp $ */
+/* $Id: basic_functions.c,v 1.555 2003/01/06 05:59:17 hyanantha Exp $ */
 
 #include php.h
 #include php_streams.h
@@ -1051,7 +1051,9 @@
PHP_MINIT(lcg) (INIT_FUNC_ARGS_PASSTHRU);
 
PHP_MINIT(dir) (INIT_FUNC_ARGS_PASSTHRU);
+#ifdef HAVE_SYSLOG_H
PHP_MINIT(syslog) (INIT_FUNC_ARGS_PASSTHRU);
+#endif
PHP_MINIT(array) (INIT_FUNC_ARGS_PASSTHRU);
PHP_MINIT(assert) (INIT_FUNC_ARGS_PASSTHRU);
PHP_MINIT(url_scanner_ex) (INIT_FUNC_ARGS_PASSTHRU);
@@ -1148,7 +1150,9 @@
PHP_RINIT(lcg) (INIT_FUNC_ARGS_PASSTHRU);
 
PHP_RINIT(filestat) (INIT_FUNC_ARGS_PASSTHRU);
+#ifdef HAVE_SYSLOG_H
PHP_RINIT(syslog) (INIT_FUNC_ARGS_PASSTHRU);
+#endif
PHP_RINIT(dir) (INIT_FUNC_ARGS_PASSTHRU);
PHP_RINIT(url_scanner_ex) (INIT_FUNC_ARGS_PASSTHRU);
 
@@ -1180,7 +1184,9 @@
 
PHP_RSHUTDOWN(fsock) (SHUTDOWN_FUNC_ARGS_PASSTHRU);
PHP_RSHUTDOWN(filestat) (SHUTDOWN_FUNC_ARGS_PASSTHRU);
+#ifdef HAVE_SYSLOG_H
PHP_RSHUTDOWN(syslog) (SHUTDOWN_FUNC_ARGS_PASSTHRU);
+#endif
PHP_RSHUTDOWN(assert) (SHUTDOWN_FUNC_ARGS_PASSTHRU);
PHP_RSHUTDOWN(url_scanner_ex) (SHUTDOWN_FUNC_ARGS_PASSTHRU);
PHP_RSHUTDOWN(streams) (SHUTDOWN_FUNC_ARGS_PASSTHRU);



Index: php4/main/php_streams.h
diff -u php4/main/php_streams.h:1.64 php4/main/php_streams.h:1.65
--- php4/main/php_streams.h:1.64Thu Jan  2 08:31:10 2003
+++ php4/main/php_streams.h Sun Jan  5 23:06:40 2003
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: php_streams.h,v 1.64 2003/01/02 13:31:10 derick Exp $ */
+/* $Id: php_streams.h,v 1.65 2003/01/06 04:06:40 pollita Exp $ */
 
 #ifndef PHP_STREAMS_H
 #define PHP_STREAMS_H
@@ -603,9 +603,9 @@
(xmsg), (xcode), 0, 0, NULL TSRMLS_CC); } } while(0)

 
 /* Give other modules access to the url_stream_wrappers_hash */
 PHPAPI HashTable *php_stream_get_url_stream_wrappers_hash();
-
+PHPAPI HashTable *php_get_stream_filters_hash();
 #endif
 
 /*
@@ -603,9 +603,9 @@

 
-/* Give other modules access to the url_stream_wrappers_hash */
+/* Give other modules access to the url_stream_wrappers_hash and stream_filters_hash 
+*/
 PHPAPI HashTable *php_stream_get_url_stream_wrappers_hash();
-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php